pub struct Session {Show 14 fields
pub au: Arc<Auth>,
pub rt: bool,
pub ip: Option<String>,
pub or: Option<String>,
pub id: Option<Uuid>,
pub ns: Option<String>,
pub db: Option<String>,
pub ac: Option<String>,
pub tk: Option<Value>,
pub rd: Option<Value>,
pub exp: Option<i64>,
pub variables: Variables,
pub new_planner_strategy: NewPlannerStrategy,
pub redact_volatile_explain_attrs: bool,
}Expand description
Specifies the current session information when processing a query.
Fields
au: Arc<Auth>The current session Auth information
rt: boolWhether realtime queries are supported
ip: Option<String>The current connection IP address
or: Option<String>The current connection origin
id: Option<Uuid>The current session ID
ns: Option<String>The currently selected namespace
db: Option<String>The currently selected database
ac: Option<String>The current access method
tk: Option<Value>The current authentication token
rd: Option<Value>The current record authentication data
exp: Option<i64>The current expiration time of the session
variables: VariablesThe variables set
new_planner_strategy: NewPlannerStrategyStrategy for the new streaming planner/executor.
redact_volatile_explain_attrs: boolWhen true, EXPLAIN ANALYZE output omits elapsed durations, making output deterministic for testing.
Implementations
Sourceimpl Session
impl Session
pub fn with_rt(self, rt: bool) -> Session
Sourcepub fn new_planner_strategy(self, strategy: NewPlannerStrategy) -> Session
pub fn new_planner_strategy(self, strategy: NewPlannerStrategy) -> Session
Set the new planner strategy for the session
Sourcepub fn for_level(level: Level, role: Role) -> Session
pub fn for_level(level: Level, role: Role) -> Session
Create a system session for a given level and role