pub enum Error {
Show 15 variants
Datastore(String),
ConnectionFailed(String),
ReadAndDeleteOnly,
Transaction(String),
TransactionTooLarge,
TransactionKeyTooLarge,
TransactionConflict(String),
TransactionFinished,
TransactionReadonly,
TransactionConditionNotMet,
TransactionKeyAlreadyExists,
UnsupportedVersionedQueries,
TimestampInvalid(String),
Internal(String),
CompactionNotSupported,
}Expand description
An error originating from the KVS (Key-Value Store) layer.
This error type abstracts storage engine details and provides generic error variants that can be used across all storage backends.
Variants
Datastore(String)
There was a problem with the underlying datastore
ConnectionFailed(String)
Failed to connect to the storage backend
ReadAndDeleteOnly
The datastore is read-and-deletion-only due to disk saturation
Transaction(String)
There was a problem with a datastore transaction
TransactionTooLarge
The transaction is too large
TransactionKeyTooLarge
The key being inserted in the transaction is too large
TransactionConflict(String)
A transaction conflict occurred and the operation should be retried
TransactionFinished
The transaction was already cancelled or committed
TransactionReadonly
The current transaction was created as read-only
TransactionConditionNotMet
The conditional value in the request was not equal
TransactionKeyAlreadyExists
The key being inserted in the transaction already exists
UnsupportedVersionedQueries
The underlying datastore does not support versioned queries
TimestampInvalid(String)
The specified timestamp is not valid for the underlying datastore
Internal(String)
There was an unknown internal error
CompactionNotSupported
Implementations