Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }

Implementations

Source

impl Transaction

pub async fn export( &self, ns: &str, db: &str, cfg: Config, chn: Sender<Vec<u8>>, ) -> Result<(), Error>

Writes the full database contents as binary SQL.

Source

impl Transaction

pub fn new( local: bool, sequences: Sequences, async_event_trigger: Arc<Notify>, tr: Transactor, ) -> Transaction

Create a new query store

pub fn is_local(&self) -> bool

Check if the transaction is local or remote

pub fn enclose(self) -> Arc<Transaction>

Enclose this transaction in an Arc

pub fn closed(&self) -> bool

Check if the transaction is finished.

If the transaction has been cancelled or committed, then this function will return true, and any further calls to functions on this transaction will result in a crate::kvs::Error::TransactionFinished error.

pub async fn cancel(&self) -> Result<(), Error>

Cancel a transaction.

This reverses all changes made within the transaction.

pub async fn commit(&self) -> Result<(), Error>

Commit a transaction.

This attempts to commit all changes made within the transaction.

pub async fn exists<K>( &self, key: &K, version: Option<u64>, ) -> Result<bool, Error>
where K: KVKey + Debug,

Check if a key exists in the datastore.

pub async fn get<K>( &self, key: &K, version: Option<u64>, ) -> Result<Option<<K as KVKey>::ValueType>, Error>
where K: KVKey + Debug,

Fetch a key from the datastore.

pub async fn getm<K>( &self, keys: Vec<K>, version: Option<u64>, ) -> Result<Vec<Option<<K as KVKey>::ValueType>>, Error>
where K: KVKey + Debug,

Retrieve a batch set of keys from the datastore.

pub async fn getp<K>( &self, key: &K, ) -> Result<Vec<(Vec<u8>, <K as KVKey>::ValueType)>, Error>
where K: KVKey + Debug,

Retrieve a specific prefix of keys from the datastore.

This function fetches key-value pairs from the underlying datastore in grouped batches.

pub async fn getr<K>( &self, rng: Range<K>, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, <K as KVKey>::ValueType)>, Error>
where K: KVKey + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches key-value pairs from the underlying datastore in grouped batches.

pub async fn del<K>(&self, key: &K) -> Result<(), Error>
where K: KVKey + Debug,

Delete a key from the datastore.

pub async fn delc<K>( &self, key: &K, chk: Option<&<K as KVKey>::ValueType>, ) -> Result<(), Error>
where K: KVKey + Debug,

Delete a key from the datastore if the current value matches a condition.

pub async fn delr<K>(&self, rng: Range<K>) -> Result<(), Error>
where K: KVKey + Debug,

Delete a range of keys from the datastore.

This function deletes entries from the underlying datastore in grouped batches.

pub async fn delp<K>(&self, key: &K) -> Result<(), Error>
where K: KVKey + Debug,

Delete a prefix of keys from the datastore.

This function deletes entries from the underlying datastore in grouped batches.

pub async fn clr<K>(&self, key: &K) -> Result<(), Error>
where K: KVKey + Debug,

Delete all versions of a key from the datastore.

pub async fn clrc<K>( &self, key: &K, chk: Option<&<K as KVKey>::ValueType>, ) -> Result<(), Error>
where K: KVKey + Debug,

Delete all versions of a key from the datastore if the current value matches a condition.

pub async fn clrr<K>(&self, rng: Range<K>) -> Result<(), Error>
where K: KVKey + Debug,

Delete all versions of a range of keys from the datastore.

This function deletes entries from the underlying datastore in grouped batches.

pub async fn clrp<K>(&self, key: &K) -> Result<(), Error>
where K: KVKey + Debug,

Delete all versions of a prefix of keys from the datastore.

This function deletes entries from the underlying datastore in grouped batches.

pub async fn set<K>( &self, key: &K, val: &<K as KVKey>::ValueType, version: Option<u64>, ) -> Result<(), Error>
where K: KVKey + Debug,

Insert or update a key in the datastore.

pub async fn put<K>( &self, key: &K, val: &<K as KVKey>::ValueType, version: Option<u64>, ) -> Result<(), Error>
where K: KVKey + Debug,

Insert a key if it doesn’t exist in the datastore.

pub async fn putc<K>( &self, key: &K, val: &<K as KVKey>::ValueType, chk: Option<&<K as KVKey>::ValueType>, ) -> Result<(), Error>
where K: KVKey + Debug,

Update a key in the datastore if the current value matches a condition.

pub async fn replace<K>( &self, key: &K, val: &<K as KVKey>::ValueType, ) -> Result<(), Error>
where K: KVKey + Debug,

Insert or replace a key in the datastore.

pub async fn keys<K>( &self, rng: Range<K>, limit: u32, skip: u32, version: Option<u64>, ) -> Result<Vec<Vec<u8>>, Error>
where K: KVKey + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches the full range of keys, in a single request to the underlying datastore.

pub async fn keysr<K>( &self, rng: Range<K>, limit: u32, skip: u32, version: Option<u64>, ) -> Result<Vec<Vec<u8>>, Error>
where K: KVKey + Debug,

Retrieve a specific range of keys from the datastore in reverse order.

This function fetches the full range of keys, in a single request to the underlying datastore.

pub async fn scan<K>( &self, rng: Range<K>, limit: u32, skip: u32, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: KVKey + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches the full range of key-value pairs, in a single request to the underlying datastore.

pub async fn scanr<K>( &self, rng: Range<K>, limit: u32, skip: u32, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: KVKey + Debug,

pub async fn count<K>( &self, rng: Range<K>, version: Option<u64>, ) -> Result<usize, Error>
where K: KVKey + Debug,

Count the total number of keys within a range in the datastore.

This function fetches the total count, in batches, with multiple requests to the underlying datastore.

pub async fn batch_keys<K>( &self, rng: Range<K>, batch: u32, version: Option<u64>, ) -> Result<Batch<Vec<u8>>, Error>
where K: KVKey + Debug,

Retrieve a batched scan over a specific range of keys in the datastore.

This function fetches the keys in batches, with multiple requests to the underlying datastore.

pub async fn batch_keys_vals<K>( &self, rng: Range<K>, batch: u32, version: Option<u64>, ) -> Result<Batch<(Vec<u8>, Vec<u8>)>, Error>
where K: KVKey + Debug,

Retrieve a batched scan over a specific range of keys in the datastore.

This function fetches the key-value pairs in batches, with multiple requests to the underlying datastore.

pub fn stream_keys( &self, rng: Range<Vec<u8>>, version: Option<u64>, limit: Option<usize>, skip: u32, dir: ScanDirection, ) -> impl Stream<Item = Result<Vec<Vec<u8>>, Error>>

Retrieve a stream of key batches over a specific range in the datastore.

This function returns a stream that yields batches of keys. The scanner:

  • Fetches an initial batch of up to 100 items
  • Fetches subsequent batches of up to 16 MiB (local) or 4 MiB (remote)
  • Prefetches the next batch while the current batch is being processed
pub fn stream_keys_vals( &self, rng: Range<Vec<u8>>, version: Option<u64>, limit: Option<usize>, skip: u32, dir: ScanDirection, prefetch: bool, ) -> impl Stream<Item = Result<Vec<(Vec<u8>, Vec<u8>)>, Error>>

Retrieve a stream of key-value batches over a specific range in the datastore.

This function returns a stream that yields batches of key-value pairs. The scanner:

  • Fetches an initial batch of up to 100 items (or 500 when prefetch is enabled)
  • Fetches subsequent batches of up to 16 MiB (local) or 4 MiB (remote)
  • When prefetch is true, prefetches the next batch while the current batch is being processed, and uses a larger initial batch size (500 items)
pub async fn new_save_point(&self) -> Result<(), Error>

Set a new save point on the transaction.

pub async fn release_last_save_point(&self) -> Result<(), Error>

Release the last save point.

pub async fn rollback_to_save_point(&self) -> Result<(), Error>

Rollback to the last save point.

pub async fn timestamp(&self) -> Result<BoxTimeStamp, Error>

Get the current monotonic timestamp

pub fn timestamp_impl(&self) -> Box<dyn TimeStampImpl>

Returns the implementation of timestamp that this transaction uses.

pub fn clear_cache(&self)

Clears all keys from the transaction cache.

pub async fn compact<K>(&self, prefix_key: Option<K>) -> Result<(), Error>
where K: KVKey + Debug,

Methods from Deref<Target = Transactor>

pub fn closed(&self) -> bool

Check if transaction is finished.

If the transaction has been cancelled or committed, then this function will return true, and any further calls to functions on this transaction will result in a crate::kvs::Error::TransactionFinished error.

pub fn writeable(&self) -> bool

Check if transaction is writeable.

If the transaction has been marked as a writeable transaction, then this function will return true. This fuction can be used to check whether a transaction allows data to be modified, and if not then the function will return a crate::kvs::Error::TransactionReadonly error when attempting to modify any data within the transaction.

pub async fn cancel(&self) -> Result<(), Error>

Cancel a transaction.

This reverses all changes made within the transaction.

pub async fn commit(&self) -> Result<(), Error>

Commit a transaction.

This attempts to commit all changes made within the transaction.

pub async fn exists<K>( &self, key: K, version: Option<u64>, ) -> Result<bool, Error>
where K: IntoBytes + Debug,

Check if a key exists in the datastore.

pub async fn get<K>( &self, key: K, version: Option<u64>, ) -> Result<Option<Vec<u8>>, Error>
where K: IntoBytes + Debug,

Fetch a key from the datastore.

pub async fn getm<K>( &self, keys: Vec<K>, version: Option<u64>, ) -> Result<Vec<Option<Vec<u8>>>, Error>
where K: IntoBytes + Debug,

Fetch many keys from the datastore.

pub async fn getp<K>(&self, key: K) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: IntoBytes + Debug,

Retrieve a specific prefixed range of keys from the datastore.

This function fetches all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn getr<K>( &self, rng: Range<K>, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: IntoBytes + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn set<K, V>( &self, key: K, val: V, version: Option<u64>, ) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Insert or update a key in the datastore.

pub async fn replace<K, V>(&self, key: K, val: V) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Insert or replace a key in the datastore.

pub async fn put<K, V>( &self, key: K, val: V, version: Option<u64>, ) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Insert a key if it doesn’t exist in the datastore.

pub async fn putc<K, V>( &self, key: K, val: V, chk: Option<V>, ) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Update a key in the datastore if the current value matches a condition.

pub async fn del<K>(&self, key: K) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete a key from the datastore.

pub async fn delc<K, V>(&self, key: K, chk: Option<V>) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Delete a key from the datastore if the current value matches a condition.

pub async fn delp<K>(&self, key: K) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete a prefixed range of keys from the datastore.

This function deletes all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn delr<K>(&self, rng: Range<K>) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete a range of keys from the datastore.

This function deletes all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn clr<K>(&self, key: K) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete all versions of a key from the datastore.

pub async fn clrc<K, V>(&self, key: K, chk: Option<V>) -> Result<(), Error>
where K: IntoBytes + Debug, V: IntoBytes + Debug,

Delete all versions of a key from the datastore if the current value matches a condition.

pub async fn clrp<K>(&self, key: K) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete all versions of a prefixed range of keys from the datastore.

This function deletes all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn clrr<K>(&self, rng: Range<K>) -> Result<(), Error>
where K: IntoBytes + Debug,

Delete all versions of a range of keys from the datastore.

This function deletes all matching key-value pairs from the underlying datastore in grouped batches.

pub async fn keys<K>( &self, rng: Range<K>, limit: ScanLimit, skip: u32, version: Option<u64>, ) -> Result<Vec<Vec<u8>>, Error>
where K: IntoBytes + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches the full range of keys without values, in a single request to the underlying datastore.

pub async fn keysr<K>( &self, rng: Range<K>, limit: ScanLimit, skip: u32, version: Option<u64>, ) -> Result<Vec<Vec<u8>>, Error>
where K: IntoBytes + Debug,

Retrieve a specific range of keys from the datastore.

This function fetches the full range of keys without values, in a single request to the underlying datastore.

pub async fn scan<K>( &self, rng: Range<K>, limit: ScanLimit, skip: u32, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: IntoBytes + Debug,

Retrieve a specific range of key-value pairs from the datastore.

This function fetches the full range of key-value pairs, in a single request to the underlying datastore.

pub async fn scanr<K>( &self, rng: Range<K>, limit: ScanLimit, skip: u32, version: Option<u64>, ) -> Result<Vec<(Vec<u8>, Vec<u8>)>, Error>
where K: IntoBytes + Debug,

Retrieve a specific range of key-value pairs from the datastore.

This function fetches the full range of key-value pairs, in a single request to the underlying datastore.

pub async fn count<K>( &self, rng: Range<K>, version: Option<u64>, ) -> Result<usize, Error>
where K: IntoBytes + Debug,

Count the total number of keys within a range in the datastore.

This function fetches the total count, in batches, with multiple requests to the underlying datastore.

pub async fn batch_keys<K>( &self, rng: Range<K>, batch: u32, version: Option<u64>, ) -> Result<Batch<Vec<u8>>, Error>
where K: IntoBytes + Debug,

Retrieve a batched scan over a specific range of keys in the datastore.

This function fetches keys, in batches, with multiple requests to the underlying datastore.

pub async fn batch_keys_vals<K>( &self, rng: Range<K>, batch: u32, version: Option<u64>, ) -> Result<Batch<(Vec<u8>, Vec<u8>)>, Error>
where K: IntoBytes + Debug,

Retrieve a batched scan over a specific range of keys in the datastore.

This function fetches key-value pairs, in batches, with multiple requests to the underlying datastore.

pub fn stream_keys<K>( &self, rng: Range<K>, version: Option<u64>, limit: Option<usize>, skip: u32, dir: Direction, ) -> impl Stream<Item = Result<Vec<Vec<u8>>, Error>>
where K: IntoBytes + Debug,

Retrieve a stream of key batches over a specific range in the datastore.

This function returns a stream that yields batches of keys. The scanner:

  • Fetches an initial batch of up to 500 items
  • Fetches subsequent batches of up to 16 MiB (local) or 4 MiB (remote)
  • Prefetches the next batch while the current batch is being processed
pub fn stream_keys_vals<K>( &self, rng: Range<K>, version: Option<u64>, limit: Option<usize>, skip: u32, dir: Direction, prefetch: bool, ) -> impl Stream<Item = Result<Vec<(Vec<u8>, Vec<u8>)>, Error>>
where K: IntoBytes + Debug,

Retrieve a stream of key-value batches over a specific range in the datastore.

This function returns a stream that yields batches of key-value pairs. The scanner:

  • Fetches an initial batch of up to 500 items (or 1000 when prefetch is enabled)
  • Fetches subsequent batches of up to 16 MiB (local) or 4 MiB (remote)
  • When prefetch is true, prefetches the next batch while the current batch is being processed, and uses a larger initial batch size (500 items)
pub async fn new_save_point(&self) -> Result<(), Error>

Set a new save point on the transaction.

pub async fn release_last_save_point(&self) -> Result<(), Error>

Release the last save point.

pub async fn rollback_to_save_point(&self) -> Result<(), Error>

Rollback to the last save point.

pub async fn timestamp(&self) -> Result<BoxTimeStamp, Error>

Get the current monotonic timestamp

pub fn timestamp_impl(&self) -> Box<dyn TimeStampImpl>

Returns the implementation of timestamp that this transaction uses.