EngineOptions

Struct EngineOptions 

pub struct EngineOptions {
    pub node_membership_refresh_interval: Duration,
    pub node_membership_check_interval: Duration,
    pub node_membership_cleanup_interval: Duration,
    pub changefeed_gc_interval: Duration,
    pub index_compaction_interval: Duration,
    pub event_processing_interval: Duration,
}
Configuration for the engine behaviour

The defaults are optimal so please only modify these if you know deliberately why you are modifying them.

Fields

node_membership_refresh_interval: Duration

Interval for refreshing node membership information

node_membership_check_interval: Duration

Interval for checking node membership status

node_membership_cleanup_interval: Duration

Interval for cleaning up inactive nodes from the cluster

changefeed_gc_interval: Duration

Interval for garbage collecting expired changefeed data

index_compaction_interval: Duration

Interval for running the index compaction process

The index compaction thread runs at this interval to process indexes that have been marked for compaction. Compaction helps optimize index performance, particularly for full-text indexes, by consolidating changes and removing unnecessary data.

Default: 5 seconds

event_processing_interval: Duration

Interval for processing queued async events.

Default: 5 seconds

Implementations