Method

Enum Method 

#[non_exhaustive]
pub enum Method {
Show 34 variants Unknown, Ping, Info, Use, Signup, Signin, Authenticate, Refresh, Invalidate, Revoke, Reset, Kill, Live, Set, Unset, Select, Insert, Create, Upsert, Update, Merge, Patch, Delete, Version, Query, Relate, Run, InsertRelation, Attach, Sessions, Detach, Begin, Commit, Cancel,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown



Ping



Info



Use



Signup



Signin



Authenticate



Refresh



Invalidate



Revoke



Reset



Kill



Live



Set



Unset



Select



Insert



Create



Upsert



Update



Merge



Patch



Delete



Version



Query



Relate



Run



InsertRelation



Attach



Sessions



Detach



Begin



Commit



Cancel

Implementations

Source

impl Method

pub fn parse_case_insensitive<S>(s: S) -> Method
where S: AsRef<str>,

Parse a Method from a str with any case

pub fn parse_case_sensitive<S>(s: S) -> Method
where S: AsRef<str>,

Parse a Method from a str in lower case

Source

impl Method

pub fn to_str(&self) -> &str

Source

impl Method

pub fn is_valid(&self) -> bool

Checks if the provided method is a valid and supported RPC method