HashMap

Struct HashMap 

pub struct HashMap<K, V, S = RandomState>(/* private fields */)
where
    K: Hash + Eq,
    V: Clone,
    S: BuildHasher + Default;
A concurrent hashmap wrapper around papaya’s HashMap.

This wrapper uses pin() internally rather than pin_owned() to avoid performance issues. All operations clone values on access, which is suitable for types that implement Clone.

Type Parameters

  • K - The key type, must implement Hash and Eq
  • V - The value type, must implement Clone
  • S - The hasher type, defaults to RandomState

Implementations

Source

impl<K, V, S> HashMap<K, V, S>
where K: Hash + Eq, V: Clone, S: BuildHasher + Default,

pub fn new() -> HashMap<K, V, S>

Creates a new empty HashMap.

pub fn insert(&self, key: K, value: V)

Inserts a key-value pair into the map.

If the map already contains this key, the value is updated.

pub fn get<Q>(&self, key: &Q) -> Option<V>
where Q: Equivalent<K> + Hash + ?Sized,

Returns a clone of the value corresponding to the key.

Returns None if the key is not present in the map.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: Equivalent<K> + Hash + ?Sized,

Returns true if the map contains a value for the specified key.

pub fn values(&self) -> Vec<V>

Returns a vector containing clones of all values in the map.

pub fn to_vec(&self) -> Vec<(K, V)>
where K: Clone,

Returns a vector containing clones of all key-value pairs in the map.

pub fn remove<Q>(&self, key: &Q)
where Q: Equivalent<K> + Hash + ?Sized,

Removes a key from the map.

Traditionally remove would return the value but this would require cloning the value, which would be an unnecessary expense when you don’t need the value. If you need the value, use take instead.

pub fn take<Q>(&self, key: &Q) -> Option<V>
where Q: Equivalent<K> + Hash + ?Sized,

Removes a key from the map and returns the value.

pub fn clear(&self)

Removes all key-value pairs from the map.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn retain<F>(&self, f: F)
where F: FnMut(&K, &V) -> bool,

Retains only the elements specified by the predicate.

In other words, removes all pairs (k, v) such that f(&k, &v) returns false.