pub struct EngineOptions {
pub node_membership_refresh_interval: Duration,
pub node_membership_check_interval: Duration,
pub node_membership_cleanup_interval: Duration,
pub changefeed_gc_interval: Duration,
pub index_compaction_interval: Duration,
pub event_processing_interval: Duration,
}Expand description
Configuration for the engine behaviour
The defaults are optimal so please only modify these if you know deliberately why you are modifying them.
Fields
node_membership_refresh_interval: DurationInterval for refreshing node membership information
node_membership_check_interval: DurationInterval for checking node membership status
node_membership_cleanup_interval: DurationInterval for cleaning up inactive nodes from the cluster
changefeed_gc_interval: DurationInterval for garbage collecting expired changefeed data
index_compaction_interval: DurationInterval for running the index compaction process
The index compaction thread runs at this interval to process indexes that have been marked for compaction. Compaction helps optimize index performance, particularly for full-text indexes, by consolidating changes and removing unnecessary data.
Default: 5 seconds
event_processing_interval: DurationInterval for processing queued async events.
Default: 5 seconds
Implementations
Sourceimpl EngineOptions
impl EngineOptions
pub fn with_node_membership_refresh_interval( self, interval: Duration, ) -> EngineOptions
pub fn with_node_membership_check_interval( self, interval: Duration, ) -> EngineOptions
pub fn with_node_membership_cleanup_interval( self, interval: Duration, ) -> EngineOptions
pub fn with_changefeed_gc_interval(self, interval: Duration) -> EngineOptions
pub fn with_index_compaction_interval(self, interval: Duration) -> EngineOptions
pub fn with_event_processing_interval(self, interval: Duration) -> EngineOptions